@@ -16,7 +16,7 @@ use strict qw(subs vars);
 # (and so on)
 
 BEGIN { eval q{ use vars qw($VERSION) } }
-$VERSION = sprintf '%d.%02d', q$Revision: 0.74 $ =~ m/(\d+)/xmsg;
+$VERSION = sprintf '%d.%02d', q$Revision: 0.75 $ =~ m/(\d+)/xmsg;
 
 BEGIN {
     my $PERL5LIB = __FILE__;
@@ -62,28 +62,6 @@ BEGIN {
         *utf8::is_utf8   = sub {   };
         *utf8::valid     = sub { 1 };
     }
-
-    # 7.6. Writing a Subroutine That Takes Filehandles as Built-ins Do
-    # in Chapter 7. File Access
-    # of ISBN 0-596-00313-7 Perl Cookbook, 2nd Edition.
-
-    sub Eoldutf8::binmode(*;$);
-    sub Eoldutf8::open(*;$@);
-
-    if ($] < 5.006) {
-
-        # 12.13. Overriding a Built-in Function in All Packages
-        # in Chapter 12. Packages, Libraries, and Modules
-        # of ISBN 0-596-00313-7 Perl Cookbook, 2nd Edition.
-
-        # avoid warning: Name "CORE::GLOBAL::binmode" used only once: possible typo at ...
-        if ($^O ne 'MacOS') {
-            *CORE::GLOBAL::binmode =
-            *CORE::GLOBAL::binmode = \&Eoldutf8::binmode;
-        }
-        *CORE::GLOBAL::open    =
-        *CORE::GLOBAL::open    = \&Eoldutf8::open;
-    }
 }
 
 # poor Symbol.pm - substitute of real Symbol.pm
@@ -1660,159 +1638,6 @@ sub _parse_path {
     return $head, $tail;
 }
 
-#
-# instead of binmode (for perl5.005 only)
-#
-sub Eoldutf8::binmode(*;$) {
-    if (@_ == 1) {
-        local $^W = 0;
-        if (ref $_[0]) {
-            my $filehandle = qualify_to_ref $_[0];
-            return eval { CORE::binmode $filehandle; };
-        }
-        else {
-            return eval { CORE::binmode *{(caller(1))[0] . "::$_[0]"}; };
-        }
-    }
-    elsif (@_ == 2) {
-        my(undef,$layer) = @_;
-        $layer =~ s/ :? encoding\($encoding_alias\) //oxms;
-        if ($layer =~ m/\A :raw \z/oxms) {
-            local $^W = 0;
-            if ($_[0] =~ m/\A (?: STDIN | STDOUT | STDERR ) \z/oxms) {
-                return eval { CORE::binmode $_[0]; };
-            }
-            elsif (ref $_[0]) {
-                my $filehandle = qualify_to_ref $_[0];
-                return eval { CORE::binmode $filehandle; };
-            }
-            else {
-                return eval { CORE::binmode *{(caller(1))[0] . "::$_[0]"}; };
-            }
-        }
-        elsif ($layer =~ m/\A :crlf \z/oxms) {
-            if ($^O !~ /\A (?: MSWin32 | NetWare | symbian | dos ) \z/oxms) {
-                croak "$0: open: Unknown binmode() layer '$layer'";
-            }
-            return;
-        }
-        else {
-            return;
-        }
-    }
-    else {
-        croak "$0: usage: binmode(FILEHANDLE [,LAYER])";
-    }
-}
-
-#
-# instead of open (for perl5.005 only)
-#
-sub Eoldutf8::open(*;$@) {
-
-    if (@_ == 0) {
-        croak "$0: usage: open(FILEHANDLE [,MODE [,EXPR]])";
-    }
-    elsif (@_ == 1) {
-        my $filehandle = gensym;
-        local $^W = 0;
-        my $expr = ${(caller(1))[0] . "::$_[0]"};
-        my $ref = \${(caller(1))[0] . "::$_[0]"};
-        *{(caller(1))[0] . "::$_[0]"} = $filehandle;
-        *{(caller(1))[0] . "::$_[0]"} = $ref;
-        return CORE::open $filehandle, $expr;
-    }
-
-    my $filehandle = gensym;
-    {
-        local $^W = 0;
-        if (not defined $_[0]) {
-            $_[0] = $filehandle;
-        }
-        else {
-            *{(caller(1))[0] . "::$_[0]"} = $filehandle;
-        }
-    }
-
-    if (@_ == 2) {
-        return CORE::open $filehandle, $_[1];
-    }
-    elsif (@_ == 3) {
-        my(undef,$mode,$expr) = @_;
-
-        $mode =~ s/ :? encoding\($encoding_alias\) //oxms;
-        if ($mode =~ s/ :crlf //oxms) {
-            if ($^O !~ /\A (?: MSWin32 | NetWare | symbian | dos ) \z/oxms) {
-                croak "$0: open: Unknown open() mode '$mode'";
-            }
-        }
-        my $binmode = $mode =~ s/ :raw //oxms;
-
-        if (eval q{ use Fcntl qw(O_RDONLY O_WRONLY O_RDWR O_CREAT O_TRUNC O_APPEND); 1 }) {
-
-            # 7.1. Opening a File
-            # in Chapter 7. File Access
-            # of ISBN 0-596-00313-7 Perl Cookbook, 2nd Edition.
-
-            my %o_flags = (
-                ''    => &O_RDONLY,
-                '<'   => &O_RDONLY,
-                '>'   => &O_WRONLY | &O_TRUNC  | &O_CREAT,
-                '>>'  => &O_WRONLY | &O_APPEND | &O_CREAT,
-                '+<'  => &O_RDWR,
-                '+>'  => &O_RDWR   | &O_TRUNC  | &O_CREAT,
-                '+>>' => &O_RDWR   | &O_APPEND | &O_CREAT,
-            );
-            if ($o_flags{$mode}) {
-                my $sysopen = CORE::sysopen $filehandle, $expr, $o_flags{$mode};
-                if ($sysopen and $binmode) {
-                    eval { CORE::binmode $filehandle; };
-                }
-                return $sysopen;
-            }
-        }
-
-        # P.747 29.2.104. open
-        # in Chapter 29: Functions
-        # of ISBN 0-596-00027-8 Programming Perl Third Edition.
-        # (and so on)
-
-        if ($mode eq '|-') {
-            my $open = CORE::open $filehandle, qq{| $expr};
-            if ($open and $binmode) {
-                eval { CORE::binmode $filehandle; };
-            }
-            return $open;
-        }
-        elsif ($mode eq '-|') {
-            my $open = CORE::open $filehandle, qq{$expr |};
-            if ($open and $binmode) {
-                eval { CORE::binmode $filehandle; };
-            }
-            return $open;
-        }
-        elsif ($mode =~ m/\A (?: \+? (?: < | > | >> ) )? \z/oxms) {
-
-            # 7.2. Opening Files with Unusual Filenames
-            # in Chapter 7. File Access
-            # of ISBN 0-596-00313-7 Perl Cookbook, 2nd Edition.
-
-            $expr =~ s#\A([ ])#./$1#oxms;
-            my $open = CORE::open $filehandle, qq{$mode $expr\0};
-            if ($open and $binmode) {
-                eval { CORE::binmode $filehandle; };
-            }
-            return $open;
-        }
-        else {
-            croak "$0: open: Unknown open() mode '$mode'";
-        }
-    }
-    else {
-        croak "$0: usage: open(FILEHANDLE [,MODE [,EXPR]])";
-    }
-}
-
 #
 # old UTF-8 character to order (with parameter)
 #
@@ -2186,120 +2011,5 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
   in the glob pattern, you can escape them with either double quotes.
   e.g. C<glob('c:/"Program Files"/*/*.dll')>.
 
-=item binary mode (Perl5.6 emulation on perl5.005)
-
-  Eoldutf8::binmode(FILEHANDLE, $disciplines);
-  Eoldutf8::binmode(FILEHANDLE);
-  Eoldutf8::binmode($filehandle, $disciplines);
-  Eoldutf8::binmode($filehandle);
-
-  * two arguments
-
-  If you are using perl5.005 other than MacPerl, OldUTF8 software emulate perl5.6's
-  binmode function. Only the point is here. See also perlfunc/binmode for details.
-
-  This function arranges for the FILEHANDLE to have the semantics specified by the
-  $disciplines argument. If $disciplines is omitted, ':raw' semantics are applied
-  to the filehandle. If FILEHANDLE is an expression, the value is taken as the
-  name of the filehandle or a reference to a filehandle, as appropriate.
-  The binmode function should be called after the open but before any I/O is done
-  on the filehandle. The only way to reset the mode on a filehandle is to reopen
-  the file, since the various disciplines may have treasured up various bits and
-  pieces of data in various buffers.
-
-  The ":raw" discipline tells Perl to keep its cotton-pickin' hands off the data.
-  For more on how disciplines work, see the open function.
-
-=item open file (Perl5.6 emulation on perl5.005)
-
-  $rc = Eoldutf8::open(FILEHANDLE, $mode, $expr);
-  $rc = Eoldutf8::open(FILEHANDLE, $expr);
-  $rc = Eoldutf8::open(FILEHANDLE);
-  $rc = Eoldutf8::open(my $filehandle, $mode, $expr);
-  $rc = Eoldutf8::open(my $filehandle, $expr);
-  $rc = Eoldutf8::open(my $filehandle);
-
-  * autovivification filehandle
-  * three arguments
-
-  If you are using perl5.005, OldUTF8 software emulate perl5.6's open function.
-  Only the point is here. See also perlfunc/open for details.
-
-  As that example shows, the FILEHANDLE argument is often just a simple identifier
-  (normally uppercase), but it may also be an expression whose value provides a
-  reference to the actual filehandle. (The reference may be either a symbolic
-  reference to the filehandle name or a hard reference to any object that can be
-  interpreted as a filehandle.) This is called an indirect filehandle, and any
-  function that takes a FILEHANDLE as its first argument can handle indirect
-  filehandles as well as direct ones. But open is special in that if you supply
-  it with an undefined variable for the indirect filehandle, Perl will automatically
-  define that variable for you, that is, autovivifying it to contain a proper
-  filehandle reference.
-
-  {
-      my $fh;                          # (uninitialized)
-      Eoldutf8::open($fh, ">logfile")     # $fh is autovivified
-          or die "Can't create logfile: $!";
-          ...                          # do stuff with $fh
-  }                                    # $fh closed here
-
-  The my $fh declaration can be readably incorporated into the open:
-
-  Eoldutf8::open my $fh, ">logfile" or die ...
-
-  The > symbol you've been seeing in front of the filename is an example of a mode.
-  Historically, the two-argument form of open came first. The recent addition of
-  the three-argument form lets you separate the mode from the filename, which has
-  the advantage of avoiding any possible confusion between the two. In the following
-  example, we know that the user is not trying to open a filename that happens to
-  start with ">". We can be sure that they're specifying a $mode of ">", which opens
-  the file named in $expr for writing, creating the file if it doesn't exist and
-  truncating the file down to nothing if it already exists:
-
-  Eoldutf8::open(LOG, ">", "logfile") or die "Can't create logfile: $!";
-
-  With the one- or two-argument form of open, you have to be careful when you use
-  a string variable as a filename, since the variable may contain arbitrarily
-  weird characters (particularly when the filename has been supplied by arbitrarily
-  weird characters on the Internet). If you're not careful, parts of the filename
-  might get interpreted as a $mode string, ignorable whitespace, a dup specification,
-  or a minus.
-  Here's one historically interesting way to insulate yourself:
-
-  $path =~ s#^([ ])#./$1#;
-  Eoldutf8::open (FH, "< $path\0") or die "can't open $path: $!";
-
-  But that's still broken in several ways. Instead, just use the three-argument
-  form of open to open any arbitrary filename cleanly and without any (extra)
-  security risks:
-
-  Eoldutf8::open(FH, "<", $path) or die "can't open $path: $!";
-
-  As of the 5.6 release of Perl, you can specify binary mode in the open function
-  without a separate call to binmode. As part of the $mode
-  argument (but only in the three-argument form), you may specify various input
-  and output disciplines.
-  To do the equivalent of a binmode, use the three argument form of open and stuff
-  a discipline of :raw in after the other $mode characters:
-
-  Eoldutf8::open(FH, "<:raw", $path) or die "can't open $path: $!";
-
-  Table 1. I/O Disciplines
-  -------------------------------------------------
-  Discipline      Meaning
-  -------------------------------------------------
-  :raw            Binary mode; do no processing
-  :crlf           Text mode; Intuit newlines
-                  (DOS-like system only)
-  :encoding(...)  Legacy encoding
-  -------------------------------------------------
-
-  You'll be able to stack disciplines that make sense to stack, so, for instance,
-  you could say:
-
-  Eoldutf8::open(FH, "<:crlf:encoding(OldUTF8)", $path) or die "can't open $path: $!";
-
-=back
-
 =cut
 
